---
categories: [it, program]
tags: [VSCode, FAQ]
lang: en
---

# Installing VSCode

<details>
<summary>📖 Contents</summary>

## Contents

- [Section](#section)
- [About](#about)

</details>

## Section

Example text.

![Alt text](img/image1.png)

_Рисунок 1 — Alt text_

Example text.

```markdown
Example text.

![Alt text](img/image1.png)

Example text.

## About
```

## About

Another text.

![Alt text 2](img/image2.png)

_Рисунок 2 — Alt text 2_

Another text.

![Alt text](img/image3.png)

_Рисунок 3 — Alt text_
